@@ -3,18 +3,22 @@ import os
 import re
 import uuid
 import docker
+import ast
 
 from src import common, config, project, log
 myLogger = log.Logger()
 
 def push(file):
+
     if file is None:
-        is_exist = os.path.exists(os.getcwd() + '/tool.json')
+        is_exist = os.path.exists(os.getcwd() + '/tool.py')
         if is_exist == False:
             myLogger.error_logger('Please initialize the tool')
-        with open(os.getcwd() + '/tool.json', 'r', encoding='utf-8') as f:
-            config_json = json.load(f)
+        with open(os.getcwd() + '/tool.py', 'r', encoding='utf-8') as f:
+            str = f.read()
+            config_json = ast.literal_eval(str)
             checkToolConfig(config_json)
+
         pushImage(config_json)
 
     if file is not None:
@@ -23,7 +27,8 @@ def push(file):
         if is_exist == False:
             myLogger.error_logger('Please enter the correct tool.json')
         with open(file, 'r', encoding='utf-8') as f:
-            config_json = json.load(f)
+            str = f.read()
+            config_json = ast.literal_eval(str)
             checkToolConfig(config_json)
         pushImage(config_json)
 
@@ -34,12 +39,12 @@ def pushImage(config_json):
         image = client.images.get(imageName)
         path = str(uuid.uuid1()).replace("-", "")
 
-        image.tag(common.get_docker_registryl() + '/' + path, tag='latest')
+        image.tag(common.get_docker_registry() + '/' + path, tag='latest')
         auth = common.get(url=common.get_cloud_base_url() + '/tool/pass')
-        for line in client.images.push(common.get_docker_registryl() + '/' + path, auth_config={'username': auth['account'], 'password': auth['password']}, stream=True, decode=True):
+        for line in client.images.push(common.get_docker_registry() + '/' + path, auth_config={'username': auth['account'], 'password': auth['password']}, stream=True, decode=True):
             if 'error' in line and line['error'] != '':
                 print(line['error'])
-                client.images.remove(common.get_docker_registryl() + '/' + path + ':latest')
+                client.images.remove(common.get_docker_registry() + '/' + path + ':latest')
                 myLogger.error_logger('Tool upload failed')
             print(line)
         try:
@@ -54,19 +59,19 @@ def pushImage(config_json):
             })
         except Exception as e:
             print(e)
-        client.images.remove(common.get_docker_registryl() + '/' + path + ':latest')
+        client.images.remove(common.get_docker_registry() + '/' + path + ':latest')
     if config_json['id'] != '':
         imageName = config_json['imageName']
         client = docker.from_env()
         image = client.images.get(imageName)
         path = str(uuid.uuid1()).replace("-", "")
 
-        image.tag(common.get_docker_registryl() + '/' + path, tag='latest')
+        image.tag(common.get_docker_registry() + '/' + path, tag='latest')
         auth = common.get(url=common.get_cloud_base_url() + '/tool/pass')
-        for line in client.images.push(common.get_docker_registryl() + '/' + path, auth_config={'username': auth['account'], 'password': auth['password']}, stream=True, decode=True):
+        for line in client.images.push(common.get_docker_registry() + '/' + path, auth_config={'username': auth['account'], 'password': auth['password']}, stream=True, decode=True):
             if 'error' in line and line['error'] != '':
                 print(line['error'])
-                client.images.remove(common.get_docker_registryl() + '/' + path + ':latest')
+                client.images.remove(common.get_docker_registry() + '/' + path + ':latest')
                 myLogger.error_logger('Tool upload failed')
             print(line)
         try:
@@ -82,7 +87,7 @@ def pushImage(config_json):
             })
         except Exception as e:
             print(e)
-        client.images.remove(common.get_docker_registryl() + '/' + path + ':latest')
+        client.images.remove(common.get_docker_registry() + '/' + path + ':latest')
 
 
 def checkToolConfig(toolConfig):
@@ -103,6 +108,8 @@ def checkToolConfig(toolConfig):
     if toolConfig['cmd'] != '':
         toolVersionCmdParamList = analysis(cmd=toolConfig['cmd'])
 
+    print("===========================toolVersionCmdParamList===========================")
+    print(toolVersionCmdParamList)
     toolInputFileList = toolConfig['inputs']
 
     inLabelSet = set()
@@ -161,4 +168,5 @@ def checkToolConfig(toolConfig):
 
 def analysis(cmd):
     response = common.get(url=common.get_cloud_base_url() + '/tool/analysis/cmd', params={"cmd": cmd})
-    return response
\ No newline at end of file
+    return response
+
